@@ -3,7 +3,7 @@
 # * A SDK for group robots of Dingtalk ( copyright )
 # * Wu Junkai wrote by python 3.7.7 , run in python 2.7.14 and python 3.8.1
 
-__version__ = '3.15.0'
+__version__ = '3.20.0'
 __all__ = ['Card','Dingapi','DingManage']
 
 try:
@@ -124,7 +124,7 @@ class _dingtalk_robot_manage(_dingtalk_robot_signature):
         if(self.is_sign):
             sign_name   = '_python_{}_signature'.format(sys.version_info.major)
             sign_mothed = getattr(self,sign_name)
-            return sig_mothed(self.webhook,self.secret)
+            return sign_mothed(self.webhook,self.secret)
         return self.webhook
 
     def __getattr__(self,text):
@@ -155,6 +155,7 @@ class _dingtalk_robot_api:
         url     = self.__robot__.url()
         headers = {'Content-Type': 'application/json'}
         data    = json.dumps({'at':self.__at__,'msgtype':self.__api__,self.__api__:kwattr}).encode("utf-8")
+        print(data)
         post    = _http_post( url, data, headers )
         self.__init__(self.__robot__)
         return eval(post)
@@ -163,7 +164,7 @@ class _dingtalk_robot_api:
         self.__at__ = kwattr
 
     def __dir__(self):
-        return ['ActionCard','FeedCard','at','link','markdown','text']
+        return ['actionCard','at','feedCard','link','markdown','text']
 
 class Dingapi(_dingtalk_robot_api):
     pass
